% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/idxAnno.R
\name{buildMSigDBIdx}
\alias{buildMSigDBIdx}
\title{Gene Set Collection Indexes from the MSigDB Database}
\usage{
buildMSigDBIdx(entrezIDs, species = "Homo sapiens", geneSets = "all",
  go.part = FALSE, min.size = 1)
}
\arguments{
\item{entrezIDs}{character, a vector that stores the Entrez Gene IDs tagged 
in your dataset. 
The order of the Entrez Gene IDs should match those of the count/expression 
matrix row names.}

\item{species}{character, determine the organism of selected gene sets: 
"human", "mouse" or "rat".}

\item{geneSets}{character, a vector determines which gene set collections 
should be used from the MSigDB.
It can take values from this list: "all", "h", "c1", "c2", "c3", "c4", "c5", 
"c6","c7". "c1"
is human specific. If "all", all available gene set collections are loaded.}

\item{go.part}{logical, whether to partition the C5 collection into the
three GO domains: CC, MF and BP or use the entire collection all together.}

\item{min.size}{integer, the minium number of genes required in a testing 
gene set}
}
\value{
indexed gene set annotation that can be used with other functions in 
the package.
Each annotation is a list of seven elements: \code{original} stores the 
original gene sets, 
\code{idx} stores the indexed gene sets,  \code{anno} that stores detailed 
annotation for each 
gene set, \code{label} a unique id that identifies the collection of gene 
sets, 
\code{featureIDs} stores the entrezIDs used in building the annotation, 
\code{species}
 stores that organism name of gene sets and \code{name}  stores the 
collection name 
to be used in the EGSEA report.
}
\description{
It prepares the MSigDB gene set collections to be used for the 
EGSEA analysis.
}
\details{
It indexes the MSigDB gene sets and loads gene set annotation.
}
\examples{
library(EGSEAdata)
data(il13.data)
v = il13.data$voom
gs.annots = buildMSigDBIdx(entrezIDs=rownames(v$E), species="human",
geneSets=c("h", "c2"))
names(gs.annots)
}

